@@ -50,11 +50,11 @@ import wxFrame2, about
 
 from odexml import Model
 import PlotFigure as PF
-from Bayes import Melding as meld
+from BIP.Bayes import Melding as meld
 from time import *
 import icones
 import quivVarFrame as QF
-from lhsframe import LHS
+from BIP.Bayes import lhs
 
 
 os.chdir(os.getcwd())
